@@ -1,6 +1,7 @@
 /*!
 This module is concerned with how `rust-script` extracts the manfiest from a script file.
 */
+use pulldown_cmark::TagEnd;
 use regex;
 
 use self::regex::Regex;
@@ -38,7 +39,7 @@ pub fn split_input(
 
     let source_in_package = package_path.as_ref().join(script_name);
     let (part_mani, source_path, source, template, sub_prelude) = match input {
-        Input::File(_, path, content) => {
+        Input::File(_, path, content, _) => {
             assert_eq!(prelude_items.len(), 0);
             let content = strip_shebang(content);
             let (manifest, source) =
@@ -56,14 +57,14 @@ pub fn split_input(
                 )
             }
         }
-        Input::Expr(content) => (
+        Input::Expr(content, _) => (
             Manifest::Toml(""),
             source_in_package,
             content.to_string(),
             Some(consts::EXPR_TEMPLATE),
             true,
         ),
-        Input::Loop(content, count) => (
+        Input::Loop(content, count, _) => (
             Manifest::Toml(""),
             source_in_package,
             content.to_string(),
@@ -152,7 +153,12 @@ fn test_split_input() {
 
     let f = |c: &str| {
         let dummy_path: ::std::path::PathBuf = "/dummy/main.rs".into();
-        Input::File("n".to_string(), dummy_path, c.to_string())
+        Input::File(
+            "n".to_string(),
+            dummy_path.clone(),
+            c.to_string(),
+            dummy_path,
+        )
     };
 
     macro_rules! r {
@@ -235,7 +241,7 @@ version = "0.1.0""#,
     assert_eq!(
         split_input(
             &f(r#"fn main() {}"#),
-            &f(r#"fn main() {}"#).base_path(),
+            f(r#"fn main() {}"#).base_path(),
             &[],
             &[],
             "",
@@ -802,7 +808,7 @@ fn scrape_markdown_manifest(content: &str) -> Option<String> {
                 let s = output.get_or_insert(String::new());
                 s.push_str(text);
             }
-            Event::End(Tag::CodeBlock(_)) if found => {
+            Event::End(TagEnd::CodeBlock) if found => {
                 found = false;
             }
             _ => (),
